@@ -9,5 +9,6 @@ from pycompass.plot import Plot
 from pycompass.sample import Sample
 from pycompass.sample_set import SampleSet
 from pycompass.annotation import Annotation
+from pycompass.sparql import Sparql
 
-__version__ = "0.7"
+__version__ = "0.7.5"
